@@ -80,16 +80,16 @@ class VantagePro2(object):
     def wake_up(self):
         '''Wakeup the station console.'''
         wait_ack = self.WAKE_ACK
-        LOGGER.info("try wake up console")
+#        LOGGER.info("try wake up console")
         self.link.write(self.WAKE_STR)
         ack = self.link.read(len(wait_ack))
         if wait_ack == ack:
-            LOGGER.info("Check ACK: OK (%s)" % (repr(ack)))
+#            LOGGER.info("Check ACK: OK (%s)" % (repr(ack)))
             return True
         #Sometimes we have a 1byte shift from Vantage Pro and that's why wake up doesn't work anymore
         #We just shift another 1byte to be aligned in the serial buffer again.
         self.link.read(1)
-        LOGGER.error("Check ACK: BAD (%s != %s)" % (repr(wait_ack), repr(ack)))
+#        LOGGER.error("Check ACK: BAD (%s != %s)" % (repr(wait_ack), repr(ack)))
         raise NoDeviceException()
 
     @retry(tries=3, delay=0.5)
@@ -105,18 +105,18 @@ class VantagePro2(object):
          :param timeout: Define this timeout when reading ACK from link﻿.
          '''
         if is_bytes(data):
-            LOGGER.info("try send : %s" % bytes_to_hex(data))
+#            LOGGER.info("try send : %s" % bytes_to_hex(data))
             self.link.write(data)
         else:
-            LOGGER.info("try send : %s" % data)
+#            LOGGER.info("try send : %s" % data)
             self.link.write("%s\n" % data)
         if wait_ack is None:
             return True
         ack = self.link.read(len(wait_ack), timeout=timeout)
         if wait_ack == ack:
-            LOGGER.info("Check ACK: OK (%s)" % (repr(ack)))
+#            LOGGER.info("Check ACK: OK (%s)" % (repr(ack)))
             return True
-        LOGGER.error("Check ACK: BAD (%s != %s)" % (repr(wait_ack), repr(ack)))
+#        LOGGER.error("Check ACK: BAD (%s != %s)" % (repr(wait_ack), repr(ack)))
         raise BadAckException()
 
     @retry(tries=3, delay=1)
@@ -126,7 +126,7 @@ class VantagePro2(object):
         self.link.write("EEBRD %s %.2d\n" % (hex_address, size))
         ack = self.link.read(len(self.ACK))
         if self.ACK == ack:
-            LOGGER.info("Check ACK: OK (%s)" % (repr(ack)))
+#            LOGGER.info("Check ACK: OK (%s)" % (repr(ack)))
             data = self.link.read(size + 2)  # 2 bytes for CRC
             if VantageProCRC(data).check():
                 return data[:-2]
@@ -134,7 +134,7 @@ class VantagePro2(object):
                 raise BadCRCException()
         else:
             msg = "Check ACK: BAD (%s != %s)" % (repr(self.ACK), repr(ack))
-            LOGGER.error(msg)
+#            LOGGER.error(msg)
             raise BadAckException()
 
     def gettime(self):
@@ -204,7 +204,7 @@ class VantagePro2(object):
             raise BadCRCException()
         else:
             self.link.write(self.ACK)
-        LOGGER.info('Starting download %d dump pages' % header['Pages'])
+#        LOGGER.info('Starting download %d dump pages' % header['Pages'])
         finish = False
         r_index = 0
         for i in range(header['Pages']):
@@ -212,10 +212,10 @@ class VantagePro2(object):
             try:
                 dump = self._read_dump_page()
             except (BadCRCException, BadDataException) as e:
-                LOGGER.error('Error: %s' % e)
+#                LOGGER.error('Error: %s' % e)
                 finish = True
                 break
-            LOGGER.info('Dump page no %d ' % dump['Index'])
+#            LOGGER.info('Dump page no %d ' % dump['Index'])
             # Get the 5 raw records
             raw_records = dump["Records"]
             # loop through archive records
@@ -231,37 +231,37 @@ class VantagePro2(object):
                 # verify that record has valid data, and store
                 r_time = record['Datetime']
                 if r_time is None:
-                    LOGGER.error('Invalid record detected')
+#                    LOGGER.error('Invalid record detected')
                     finish = True
                     break
                 elif r_time <= stop_date:
                     if start_date < r_time:
                         not_in_range = False
                         msg = "Record-%.4d - Datetime : %s" % (r_index, r_time)
-                        LOGGER.info(msg)
+#                        LOGGER.info(msg)
                         yield record
                     else:
                         not_in_range = True
-                        LOGGER.info('The record is not in the datetime range')
+#                        LOGGER.info('The record is not in the datetime range')
                 else:
-                    LOGGER.error('Invalid record detected')
+#                    LOGGER.error('Invalid record detected')
                     finish = True
                     break
                 r_index += 1
             if finish:
-                LOGGER.info('Canceling download : Finish')
+#                LOGGER.info('Canceling download : Finish')
                 self.link.write(self.ESC)
                 break
             elif not_in_range:
                 msg = 'Page is not in the datetime range'
-                LOGGER.info('Canceling download : %s' % msg)
+#                LOGGER.info('Canceling download : %s' % msg)
                 self.link.write(self.ESC)
                 break
             else:
                 if header['Pages'] - 1 == i:
-                    LOGGER.info('Start downloading next page')
+#                    LOGGER.info('Start downloading next page')
                 self.link.write(self.ACK)
-        LOGGER.info('Pages Downloading process was finished')
+#        LOGGER.info('Pages Downloading process was finished')
 
     @cached_property
     def archive_period(self):
