@@ -74,10 +74,10 @@ class VantageProCRC(object):
         '''Perform CRC check on raw serial data, return true if valid.
         A valid CRC == 0.'''
         if len(self.data) != 0 and self.checksum == 0:
-            LOGGER.info("Check CRC : OK")
+#            LOGGER.info("Check CRC : OK")
             return True
         else:
-            LOGGER.error("Check CRC : BAD")
+#            LOGGER.error("Check CRC : BAD")
             return False
 
 
@@ -174,7 +174,7 @@ class LoopDataParserRevB(DataParser):
         self['LeafTemps'] = struct.unpack(b'4B', self['LeafTemps'])
 
         # Inside Alarms bits extraction, only 7 bits are used
-        self['AlarmIn'] = bytes_to_binary(self.raw_bytes[70])
+        self['AlarmIn'] = bytes_to_binary(self.raw_bytes[70:71])
         self['AlarmInFallBarTrend'] = int(self['AlarmIn'][0])
         self['AlarmInRisBarTrend'] = int(self['AlarmIn'][1])
         self['AlarmInLowTemp'] = int(self['AlarmIn'][2])
@@ -184,7 +184,7 @@ class LoopDataParserRevB(DataParser):
         self['AlarmInTime'] = int(self['AlarmIn'][6])
         del self['AlarmIn']
         # Rain Alarms bits extraction, only 5 bits are used
-        self['AlarmRain'] = bytes_to_binary(self.raw_bytes[71])
+        self['AlarmRain'] = bytes_to_binary(self.raw_bytes[71:72])
         self['AlarmRainHighRate'] = int(self['AlarmRain'][0])
         self['AlarmRain15min'] = int(self['AlarmRain'][1])
         self['AlarmRain24hour'] = int(self['AlarmRain'][2])
@@ -192,7 +192,7 @@ class LoopDataParserRevB(DataParser):
         self['AlarmRainETDaily'] = int(self['AlarmRain'][4])
         del self['AlarmRain']
         # Oustide Alarms bits extraction, only 13 bits are used
-        self['AlarmOut'] = bytes_to_binary(self.raw_bytes[72])
+        self['AlarmOut'] = bytes_to_binary(self.raw_bytes[72:73])
         self['AlarmOutLowTemp'] = int(self['AlarmOut'][0])
         self['AlarmOutHighTemp'] = int(self['AlarmOut'][1])
         self['AlarmOutWindSpeed'] = int(self['AlarmOut'][2])
@@ -210,7 +210,7 @@ class LoopDataParserRevB(DataParser):
         del self['AlarmOut']
         # AlarmExTempHum bits extraction, only 3 bits are used, but 7 bytes
         for i in range(1, 8):
-            data = self.raw_bytes[73 + i]
+            data = self.raw_bytes[73 + i:74 + i]
             self['AlarmExTempHum'] = bytes_to_binary(data)
             self['AlarmEx%.2dLowTemp' % i] = int(self['AlarmExTempHum'][0])
             self['AlarmEx%.2dHighTemp' % i] = int(self['AlarmExTempHum'][1])
@@ -219,8 +219,7 @@ class LoopDataParserRevB(DataParser):
         del self['AlarmExTempHum']
         # AlarmSoilLeaf 8bits, 4 bytes
         for i in range(1, 5):
-            data = self.raw_bytes[81 + i]
-            LOGGER.error(self.raw_bytes)
+            data = self.raw_bytes[81 + i:82 + i]
             self['AlarmSoilLeaf'] = bytes_to_binary(data)
             self['Alarm%.2dLowLeafWet' % i] = int(self['AlarmSoilLeaf'][0])
             self['Alarm%.2dHighLeafWet' % i] = int(self['AlarmSoilLeaf'][0])
